pub struct HttpLogger { /* private fields */ }Expand description
A middleware for logging HTTP requests.
Implementations
Sourceimpl HttpLogger
impl HttpLogger
Sourcepub fn new<T: HttpLoggerBackend + 'static>(backend: T) -> Self
pub fn new<T: HttpLoggerBackend + 'static>(backend: T) -> Self
Create a new HTTP logger from a backend
Sourcepub fn new_with_locked<T: HttpLoggerBackend + 'static>(
backend: Arc<RwLock<T>>,
) -> Self
pub fn new_with_locked<T: HttpLoggerBackend + 'static>( backend: Arc<RwLock<T>>, ) -> Self
Create a new HTTP logger from a backend that is encapsulated in an Arc<Rwlock<_>>.
This can be used in order to maintain access to the backend inside the RwLock
even after passing it into the HttpLogger.
Sourcepub async fn log_request(
&self,
start_time: SystemTime,
request: &Request<Vec<u8>>,
response: Option<&Response<Bytes>>,
)
pub async fn log_request( &self, start_time: SystemTime, request: &Request<Vec<u8>>, response: Option<&Response<Bytes>>, )
Log a HTTP request.